TestFramesOpen
open | ../tests/html/Frames.html |
selectFrame | mainFrame |
verifyLocation | */tests/html/test_open.html |
verifyTextPresent | This is a test of the open command. |
open | ../tests/html/test_page.slow.html |
verifyLocation | */tests/html/test_page.slow.html |
verifyTitle | Slow Loading Page |
setTimeout | 5000 |
open | ../tests/html/test_open.html |
open | ../tests/html/test_open.html |
open | ../tests/html/test_open.html |